API Reference
=============

Core module
-----------

.. toctree::
   :maxdepth: 1

   vowpalwabbit

Optional modules
----------------

.. toctree::
   :maxdepth: 1

   vowpalwabbit.dftovw
   vowpalwabbit.sklearn


Implementation/internal modules
-------------------------------

.. toctree::
   :maxdepth: 1

   vowpalwabbit.pyvw
   vowpalwabbit.pyvw.pylibvw


Migration guides
----------------

.. toctree::
   :maxdepth: 1

   python_8110_900_migration_guide
